package com.srs.system.mapper;

import java.util.List;

import com.srs.system.domain.SysSuggestion;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 优化建议Mapper接口
 *
 * @author srs
 * @date 2025-04-29
 */
public interface SysSuggestionMapper extends BaseMapper<SysSuggestion> {
    /**
     * 查询优化建议
     *
     * @param id 优化建议主键
     * @return 优化建议
     */
    public SysSuggestion selectSysSuggestionById(Long id);

    /**
     * 查询优化建议列表
     *
     * @param sysSuggestion 优化建议
     * @return 优化建议集合
     */
    List<SysSuggestion> selectSysSuggestionList(SysSuggestion sysSuggestion);

    /**
     * 新增优化建议
     *
     * @param sysSuggestion 优化建议
     * @return 结果
     */
    int insertSysSuggestion(SysSuggestion sysSuggestion);

    /**
     * 修改优化建议
     *
     * @param sysSuggestion 优化建议
     * @return 结果
     */
    int updateSysSuggestion(SysSuggestion sysSuggestion);

    /**
     * 删除优化建议
     *
     * @param id 优化建议主键
     * @return 结果
     */
    int deleteSysSuggestionById(Long id);

    /**
     * 批量删除优化建议
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysSuggestionByIds(Long[] ids);
}
